//Set defaults
import Bluebird from "bluebird";
global.Promise = Bluebird;
//Base Events
import IKTransaction from "./src/BaseEvent/IKTransaction.js";
import IKProcess from "./src/BaseEvent/IKProcess.js";
//Extra Events
import IKRouter from "./src/IKRouter.js";
import IKEventProcessor from "./src/IKEventProcessor.js";
import IKDynamoStream from "./src/IKDynamoStream.js";
import IKStepTransaction from "./src/IKStepTransaction.js";
//Extra components
import IKMailer from "./src/Mailer/IKMailer.js";
import IKValidation from "./src/Validation/IKValidation.js";
//Responses
import IKResponse from "./src/API/IKResponse.js";
//Helpers
import Utils from "./src/API/IKUtils.js";
//Cache
//Redis
import IKRedis from "./src/Cache/Redis/IKRedis.js";
//Database
//PSQL
import IKDBPSQLQuery from "./src/Database/PSQL/IKDBBaseQuery.js";
//DDB
import IKDBQueryScan from "./src/Database/DDB/IKDBQueryScan.js";
import IKDBQueryGet from "./src/Database/DDB/IKDBQueryGet.js";
import IKDBQueryPut from "./src/Database/DDB/IKDBQueryPut.js";
import IKDBQueryUpdate from "./src/Database/DDB/IKDBQueryUpdate.js";
import IKDBQueryDelete from "./src/Database/DDB/IKDBQueryDelete.js";
import IKDBQueryBatchWrite from "./src/Database/DDB/IKDBQueryBatchWrite.js";
import IKDBQueryBatchGet from "./src/Database/DDB/IKDBQueryBatchGet.js";
import IKDBQueryTransactionalWrite from "./src/Database/DDB/IKDBQueryTransactionalWrite.js";
import { IKDBExpressionOperator } from "./src/Database/DDB/IKDBBaseExpression.js";
//
export default {
  //Base Events
  IKTransaction,
  IKProcess,
  //Extra Events
  IKRouter,
  IKEventProcessor,
  IKDynamoStream,
  IKStepTransaction,
  //Extra components
  IKMailer,
  IKValidation,
  //Responses
  IKResponse,
  IKBadRequestResponse: IKResponse.IKBadRequestResponse,
  IKUnauthorizedResponse: IKResponse.IKUnauthorizedResponse,
  IKMissingParamResponse: IKResponse.IKMissingParamResponse,
  IKMissingQueryResponse: IKResponse.IKMissingQueryResponse,
  IKSuccessResponse: IKResponse.IKSuccessResponse,
  IKSuccessStreamResponse: IKResponse.IKSuccessStreamResponse,
  IKSuccessNoContentResponse: IKResponse.IKSuccessNoContentResponse,
  IKBadRequestResponseWithRollback: IKResponse.IKBadRequestResponseWithRollback,
  IKStepFunctionResponse: IKResponse.IKStepFunctionResponse,
  IKSimpleResponse: IKResponse.IKSimpleResponse,
  //Helpers
  Utils,
  //Cache
  //Redis
  IKRedis,
  //Database
  //PSQL
  IKDBPSQLQuery,
  //DDB
  IKDBDDBQueryScan: IKDBQueryScan,
  IKDBDDBQueryGet: IKDBQueryGet,
  IKDBDDBQueryPut: IKDBQueryPut,
  IKDBDDBQueryUpdate: IKDBQueryUpdate,
  IKDBDDBQueryDelete: IKDBQueryDelete,
  IKDBDDBQueryBatchWrite: IKDBQueryBatchWrite,
  IKDBDDBQueryBatchGet: IKDBQueryBatchGet,
  IKDBDDBQueryTransactionalWrite: IKDBQueryTransactionalWrite,
  IKDBDDBExpressionOperator: IKDBExpressionOperator,
  //Legacy
  IKDBQueryScan,
  IKDBQueryGet,
  IKDBQueryPut,
  IKDBQueryUpdate,
  IKDBQueryDelete,
  IKDBQueryBatchWrite,
  IKDBQueryBatchGet,
  IKDBQueryTransactionalWrite,
  IKDBExpressionOperator,
};
