import IKDBBaseQuery from './IKDBBaseQuery.js';
import Utils from './../../API/IKUtils.js';
//
export default class IKDBQueryBatchGet extends IKDBBaseQuery {
  constructor(optIndexName) {
    super(optIndexName);
  }
  async run(dbManager, appendingItems) {
    const localConsole = (dbManager.transaction ? dbManager.transaction.logger : console);
    const resp = await this.rawRun(dbManager, appendingItems);
    if (resp.Items) {
      let unmarshalled = Utils.decapsulateForDB(resp.Items);
      localConsole.debug('Parsed result: ', unmarshalled);
      //Check for appending items from previous query
      if (appendingItems && appendingItems.length > 0) {
        unmarshalled = unmarshalled.concat(appendingItems);
      }
      return unmarshalled;
    } return null;
  }
  async rawRun(dbManager, appendingItems) {
    const localConsole = (dbManager.transaction ? dbManager.transaction.logger : console);
    const query = {
      ...this._rawQuery()
    };
    localConsole.log('Batch getting items: ', query, appendingItems ? appendingItems.length : null);
    const resp = await dbManager.connection.batchGetItem(query);
    localConsole.debug('Raw result: ', resp);
    this._incrementTrackerStats(resp, dbManager);
    return resp;
  }

  /* tracker support */
  _incrementTrackerStats(resp, dbManager) {
    if (resp && resp.ConsumedCapacity && resp.ConsumedCapacity.CapacityUnits) dbManager.stats.readUnits += parseFloat(resp.ConsumedCapacity.CapacityUnits);
  }
}
